@@ -17,6 +17,6 @@ C
       DO 10 I = 1, N
         IF(DABS(RESIDS(I)/SCINIT) .LT. PARAM) HUBCOR = HUBCOR + 1.0D0
 10    CONTINUE
-      HUBCOR = HUBCOR/DFLOAT(N)
+      HUBCOR = HUBCOR/DBLE(N)
       RETURN
       END
